pygeodesy.fsums.Fsum2Tuple

Package pygeodesy :: Module fsums :: Class Fsum2Tuple |
[frames] | no frames]

# Class Fsum2Tuple

       object --+
                |
            tuple --+
                    |
       object --+   |
                |   |
     named._Named --+
                    |
    named._NamedTuple --+
                        |
                       Fsum2Tuple

2-Tuple `(fsum, residual)` with the precision running `fsum` and the `residual`, the sum of the remaining partials. Each item is `float` or `int`.

Note: If the `residual is INT0`, the `fsum` is considered to be exact, see method Fsum2Tuple.is_exact.

Instance Methods
__abs__(self) |
__bool__(self) |
__eq__(self, other) x==y |
__float__(self) |
__ge__(self, other) x>=y |
__gt__(self, other) x>y |
__le__(self, other) x<=y |
__lt__(self, other) x<y |
__int__(self) |
__ne__(self, other) x!=y |
__neg__(self) |
__nonzero__(self) |
__pos__(self) |
as_integer_ratio(self) Return this instance as the ratio of 2 integers. |
Fsum_(self, *xs, **name_f2product_nonfinites_RESIDUAL) Return this `Fsum2Tuple` as an Fsum plus some `xs`. |
is_exact(self) Is this Fsum2Tuple considered to be exact? (`bool`). |
is_finite(self) Is this Fsum2Tuple `finite`? (`bool`). |
is_integer(self) Is this Fsum2Tuple `integer`? (`bool`). |
signOf(self, **res) Like method Fsum.signOf. |
toStr(self, fmt='g', **prec_sep) Return this Fsum2Tuple as string (`str`). |
Inherited from `named._NamedTuple`: `__delattr__`, `__getattr__`, `__hash__`, `__repr__`, `__setattr__`, `__str__`, `dup`, `items`, `iteritems`, `iterunits`, `reUnit`, `toRepr`, `toUnits`, `units` Inherited from `tuple`: `__add__`, `__contains__`, `__getattribute__`, `__getitem__`, `__getnewargs__`, `__getslice__`, `__iter__`, `__len__`, `__mul__`, `__rmul__`, `count`, `index` Inherited from `named._Named`: `__format__`, `__imatmul__`, `__matmul__`, `__rmatmul__`, `attrs`, `classof`, `copy`, `methodname`, `rename`, `renamed`, `toStr2` Inherited from `object`: `__init__`, `__reduce__`, `__reduce_ex__`, `__sizeof__`, `__subclasshook__`

Static Methods
Inherited from `named._NamedTuple`: `__new__`

Properties
Inherited from `named._Named`: `classname`, `classnaming`, `iteration`, `name`, `named`, `named2`, `named3`, `named4`, `sizeof`, `typename` Inherited from `object`: `__class__`

Method Details

### __eq__ (self, other) (Equality operator) |
x==y Overrides: tuple.__eq__ (inherited documentation)

### __ge__ (self, other) (Greater-than-or-equals operator) |
x>=y Overrides: tuple.__ge__ (inherited documentation)

### __gt__ (self, other) (Greater-than operator) |
x>y Overrides: tuple.__gt__ (inherited documentation)

### __le__ (self, other) (Less-than-or-equals operator) |
x<=y Overrides: tuple.__le__ (inherited documentation)

### __lt__ (self, other) (Less-than operator) |
x<y Overrides: tuple.__lt__ (inherited documentation)

### __ne__ (self, other) |
x!=y Overrides: tuple.__ne__ (inherited documentation)

### as_integer_ratio (self) |
Return this instance as the ratio of 2 integers. See Also: Method Fsum.as_integer_ratio for further details.

### is_finite (self) |
Is this Fsum2Tuple `finite`? (`bool`). See Also: Function isfinite.

### toStr (self, fmt='g', **prec_sep) |
Return this Fsum2Tuple as string (`str`). Arguments: `fmt` - Optional `float` format (`letter`). `prec_sep` - Optional keyword arguments for function fstr. Returns: Tuple items (`str`). Overrides: named._Named.toStr